@@ -16,13 +16,15 @@
 URL patterns for the OpenStack Dashboard.
 """
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from disaster_recovery.api.rest import rest_api
 
 urlpatterns = [
-    url(r'^api/clients/$', rest_api.Clients.as_view(), name="api_clients"),
-    url(r'^api/actions/$', rest_api.ActionList.as_view(), name="api_actions"),
-    url(r'^api/actions/job/(?P<job_id>[^/]+)?$',
-        rest_api.Actions.as_view(), name="api_actions_in_job"),
+    re_path(r'^api/clients/$', rest_api.Clients.as_view(),
+            name="api_clients"),
+    re_path(r'^api/actions/$', rest_api.ActionList.as_view(),
+            name="api_actions"),
+    re_path(r'^api/actions/job/(?P<job_id>[^/]+)?$',
+            rest_api.Actions.as_view(), name="api_actions_in_job"),
 ]
